import type { JSX } from "solid-js/jsx-runtime";
import { DefaultTheme } from "solid-styled-components";
declare type LowercaseCharacter = "a" | "b" | "c" | "d" | "e" | "f" | "g" | "h" | "i" | "j" | "k" | "l" | "m" | "n" | "o" | "p" | "q" | "r" | "s" | "t" | "u" | "v" | "w" | "x" | "y" | "z";
declare type AllCharacter = LowercaseCharacter | Uppercase<LowercaseCharacter>;
declare type NonEmptyString = `${AllCharacter}${string}`;
declare type CSSCustomProperties = `var(--${NonEmptyString})`;
declare type LengthUnit = "vmin" | "vmax" | "vh" | "vw" | "%" | "ch" | "ex" | "em" | "rem" | "in" | "cm" | "mm" | "pt" | "pc" | "px";
export declare type CSSLength = `${number}${LengthUnit}` | CSSCustomProperties;
export declare function checkIsCSSLength(str: string): str is CSSLength;
export interface Spacing {
    none: CSSLength;
    xxs: CSSLength;
    xs: CSSLength;
    sm: CSSLength;
    md: CSSLength;
    mdLg: CSSLength;
    lg: CSSLength;
    lgXl: CSSLength;
    xl: CSSLength;
    xlXXl: CSSLength;
    xxl: CSSLength;
}
export declare const spacing: Spacing;
export declare type BaseTheme = Record<string, CSSLength | string | number>;
declare type ThemeOrDefaultSpace<T> = T extends {
    space: BaseTheme;
} ? T["space"] : keyof Spacing;
declare type SpacingOptions = ThemeOrDefaultSpace<DefaultTheme>;
declare type MaybeValue = CSSLength | undefined;
declare type GetSpacingValue = (spacingKey: SpacingOptions, theme?: Partial<BaseTheme>) => MaybeValue;
export declare const getSpacingValue: GetSpacingValue;
export interface StackProps {
    gutter?: SpacingOptions;
}
export declare const Stack: ((props: StackProps & JSX.HTMLAttributes<HTMLDivElement>) => JSX.Element) & {
    className: (props: StackProps & JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type MinItemWidth = number | CSSLength;
export interface GridProps {
    gutter?: SpacingOptions;
    minItemWidth?: MinItemWidth;
}
export declare const Grid: ((props: GridProps & JSX.HTMLAttributes<HTMLDivElement>) => JSX.Element) & {
    className: (props: GridProps & JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type MaxWidth = number | CSSLength;
export interface CenterProps {
    maxWidth?: MaxWidth;
    centerText?: boolean;
    centerChildren?: boolean;
}
export declare const Center: ((props: CenterProps & JSX.HTMLAttributes<HTMLDivElement>) => JSX.Element) & {
    className: (props: CenterProps & JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type Basis = CSSLength | number;
export interface ColumnDropProps {
    gutter?: SpacingOptions;
    basis?: Basis;
    noStretchedColumns?: boolean;
}
export declare const ColumnDrop: ((props: ColumnDropProps & JSX.HTMLAttributes<HTMLDivElement>) => JSX.Element) & {
    className: (props: ColumnDropProps & JSX.HTMLAttributes<HTMLDivElement>) => string;
};
declare type Ratio = [number, number] | `${number}/${number}`;
export interface FrameProps {
    ratio?: Ratio;
    position?: string;
}
export declare const Frame: ((props: FrameProps & JSX.HTMLAttributes<HTMLDivElement>) => JSX.Element) & {
    className: (props: FrameProps & JSX.HTMLAttributes<HTMLDivElement>) => string;
};
export {};
